==> pgljupyter-0.1.10.tar.gz: package/lib/labplugin.js <==
import { IJupyterWidgetRegistry } from '@jupyter-widgets/base';
import { pythonIcon, LabIcon } from '@jupyterlab/ui-components';
import { Mode } from "@jupyterlab/codemirror";
import * as widgets from './widgets/widgets';
import * as editors from './widgets/editors';
import * as models from './widgets/models';
import bgeom from './widgets/geom';
import { MODULE_NAME, MODULE_VERSION } from './version';
import { IRenderMimeRegistry } from '@jupyterlab/rendermime';
import { MimeDocumentFactory } from '@jupyterlab/docregistry';
const registerWidgets = (widgetRegistry) => {
    widgetRegistry.registerWidget({
        name: MODULE_NAME,
        version: MODULE_VERSION,
        exports: Object.assign(Object.assign(Object.assign({}, widgets), editors), models)
    });
};
const registerLpyFileType = (app) => {
    Mode.getModeInfo().push({
        name: 'Lpy',
        mime: 'text/x-python',
        mode: 'python',
        ext: ['lpy']
    });
    app.docRegistry.addFileType({
        name: 'lpy',
        displayName: 'Lpy File',
        extensions: ['.lpy'],
        mimeTypes: ['text/x-python'],
        icon: pythonIcon
    });
};
const registerGeomFileType = (app, mimeRegistry) => {
    mimeRegistry.addFactory(bgeom.rendererFactory);
    bgeom.fileTypes.forEach((ft) => {
        if (ft.icon) {
            ft = Object.assign(Object.assign({}, ft), { icon: LabIcon.resolve({ icon: ft.icon }) });
        }
        app.docRegistry.addFileType(ft);
    });
    const options = bgeom.documentWidgetFactoryOptions;
    options.forEach(option => {
        const factory = new MimeDocumentFactory({
            renderTimeout: option.renderTimeout,
            dataType: option.dataType,
            rendermime: mimeRegistry,
            modelName: option.modelName,
            name: option.name,
            primaryFileType: app.docRegistry.getFileType(option.primaryFileType),
            fileTypes: option.fileTypes,
            defaultFor: option.defaultFor,
            defaultRendered: option.defaultRendered
        });
        app.docRegistry.addWidgetFactory(factory);
    });
};
const plugin = {
    id: 'pgljupyter:plugin',
    requires: [IJupyterWidgetRegistry, IRenderMimeRegistry],
    activate: (app, widgetRegistry, mimeRegistry) => {
        registerWidgets(widgetRegistry);
        registerGeomFileType(app, mimeRegistry);
        registerLpyFileType(app);
    },
    autoStart: true
};
export default plugin;
//# sourceMappingURL=labplugin.js.map

==> pgljupyter-1.0.0.tar.gz: package/lib/labplugin.js <==
import { IJupyterWidgetRegistry } from '@jupyter-widgets/base';
import { pythonIcon, LabIcon } from '@jupyterlab/ui-components';
import { Mode } from "@jupyterlab/codemirror";
import * as widgets from './widgets/widgets';
import * as editors from './widgets/editors';
import * as models from './widgets/models';
import bgeom from './widgets/geom';
import { MODULE_NAME, MODULE_VERSION } from './version';
import { IRenderMimeRegistry } from '@jupyterlab/rendermime';
import { MimeDocumentFactory } from '@jupyterlab/docregistry';
const registerWidgets = (widgetRegistry) => {
    widgetRegistry.registerWidget({
        name: MODULE_NAME,
        version: MODULE_VERSION,
        exports: Object.assign(Object.assign(Object.assign({}, widgets), editors), models)
    });
};
const registerLpyFileType = (app) => {
    Mode.getModeInfo().push({
        name: 'Lpy',
        mime: 'text/x-python',
        mode: 'python',
        ext: ['lpy']
    });
    app.docRegistry.addFileType({
        name: 'lpy',
        displayName: 'Lpy File',
        extensions: ['.lpy'],
        mimeTypes: ['text/x-python'],
        icon: pythonIcon
    });
};
const registerGeomFileType = (app, mimeRegistry) => {
    mimeRegistry.addFactory(bgeom.rendererFactory);
    bgeom.fileTypes.forEach((ft) => {
        if (ft.icon) {
            ft = Object.assign(Object.assign({}, ft), { icon: LabIcon.resolve({ icon: ft.icon }) });
        }
        app.docRegistry.addFileType(ft);
    });
    const option = bgeom.documentWidgetFactoryOptions;
    const factory = new MimeDocumentFactory({
        renderTimeout: option.renderTimeout,
        dataType: option.dataType,
        rendermime: mimeRegistry,
        modelName: option.modelName,
        name: option.name,
        primaryFileType: app.docRegistry.getFileType(option.primaryFileType),
        fileTypes: option.fileTypes,
        defaultFor: option.defaultFor,
        defaultRendered: option.defaultRendered
    });
    app.docRegistry.addWidgetFactory(factory);
};
const plugin = {
    id: 'pgljupyter:plugin',
    requires: [IJupyterWidgetRegistry, IRenderMimeRegistry],
    activate: (app, widgetRegistry, mimeRegistry) => {
        debugger;
        registerWidgets(widgetRegistry);
        registerGeomFileType(app, mimeRegistry);
        registerLpyFileType(app);
    },
    autoStart: true
};
export default plugin;
//# sourceMappingURL=labplugin.js.map
